@@ -19,7 +19,6 @@
 """
 opsi configuration daemon (opsiconfd)
 
-.. versionadded:: 4.0.4
 
 :copyright:uib GmbH <info@uib.de>
 :author: Jan Schneider <j.schneider@uib.de>
@@ -28,12 +27,7 @@ opsi configuration daemon (opsiconfd)
 :license: GNU Affero General Public License version 3
 """
 
-__version__ = "4.0.6.1"
-
-# Twisted imports
-from twisted.internet import epollreactor
-epollreactor.install()
-from twisted.internet import reactor
+from __future__ import print_function
 
 import getopt
 import os
@@ -51,18 +45,23 @@ try:
 except ImportError:
 	avahi = None
 
-from signal import *
-from ctypes import *
+from datetime import datetime
+from signal import signal, SIGHUP, SIGINT, SIGTERM
+from ctypes import CDLL
+
+from twisted.internet import epollreactor
+epollreactor.install()
+from twisted.internet import reactor
 
 from OPSI.Application import Application
 from OPSI.Logger import Logger, LOG_NONE, LOG_WARNING, LOG_NOTICE
 from OPSI.web2 import server
-from OPSI.Util import getfqdn
+from OPSI.Util import getfqdn, removeUnit
 from OPSI.Util.File import IniFile
 from OPSI.Util.AMP import OpsiProcessProtocolFactory
 from OPSI.Util.MessageBus import MessageBusServer
-from OPSI.Types import *
-
+from OPSI.Types import (forceBool, forceFilename, forceHostId, forceInt,
+						forceNetworkAddress, forceUnicode)
 from OPSI.System import which, execute
 from OPSI.System.Posix import daemonize
 from OPSI.Backend.BackendManager import BackendManager
@@ -75,6 +74,8 @@ from monitoring import ResourceOpsiconfdMonitoring
 from session import OpsiconfdSessionHandler
 from omb import MessageBusService, OpsiconfdHTTPFactory, OpsiconfdHTTPChannel
 
+__version__ = "4.0.6.11"
+
 logger = Logger()
 
 
@@ -111,7 +112,7 @@ class ZeroconfService(object):
 			avahi.DBUS_INTERFACE_ENTRY_GROUP
 		)
 
-		g.AddService(avahi.IF_UNSPEC, avahi.PROTO_UNSPEC,dbus.UInt32(0),
+		g.AddService(avahi.IF_UNSPEC, avahi.PROTO_UNSPEC, dbus.UInt32(0),
 				self._name, self._serviceType, self._domain, self._host,
 				dbus.UInt16(self._port), self._text)
 
@@ -125,29 +126,33 @@ class ZeroconfService(object):
 
 class Opsiconfd(OpsiService):
 	def __init__(self, config):
-		self.config             = config
-		self._running           = False
-		self._backend           = None
-		self._root              = None
-		self._site              = None
-		self._httpPort          = None
-		self._httpsPort         = None
-		self._sessionHandler    = None
-		self._statistics        = None
-		self._zeroconfService   = None
-		self._messageBusServer  = None
+		self.config = config
+		self._running = False
+		self._backend = None
+		self._root = None
+		self._site = None
+		self._httpPort = None
+		self._httpsPort = None
+		self._sessionHandler = None
+		self._statistics = None
+		self._zeroconfService = None
+		self._messageBusServer = None
 		self._messageBusService = None
-		self._socket            = None
-		self._debugShell        = None
+		self._socket = None
+		self._debugShell = None
 
 		self.authFailureCount = {}
 
 		self._setOpsiLogging()
 		self._setTwistedLogging()
 
-		logger.comment(	"\n==================================================================\n" \
-				+ "=             opsi configuration service starting                =\n" \
-				+ "==================================================================\n")
+		if 'startTime' not in self.config:
+			self.config['startTime'] = datetime.now()
+
+		logger.comment("""
+==================================================================
+=             opsi configuration service starting                =
+==================================================================""")
 
 	def getInterface(self):
 		return self.getBackend().backend_getInterface()
@@ -189,7 +194,7 @@ class Opsiconfd(OpsiService):
 			if self._backend:
 				try:
 					self._backend.backend_exit()
-				except:
+				except Exception:
 					pass
 			if self._socket:
 				self._socket.stopListening()
@@ -236,9 +241,9 @@ class Opsiconfd(OpsiService):
 		logger.logWarnings()
 		self.config['machineLogs'] = False
 		if self.config['logFile']:
-			if (self.config['logFile'].find('%m') != -1):
+			if '%m' in self.config['logFile']:
 				self.config['machineLogs'] = True
-			logger.setLogFile( self.config['logFile'].replace('%m', 'opsiconfd') )
+			logger.setLogFile(self.config['logFile'].replace('%m', 'opsiconfd'))
 
 		if self.config['logFormat']:
 			logger.setLogFormat(self.config['logFormat'])
@@ -251,14 +256,14 @@ class Opsiconfd(OpsiService):
 	def _createBackendInstance(self):
 		logger.info(u"Creating backend instance")
 		self._backend = BackendManager(
-			dispatchConfigFile = self.config['dispatchConfigFile'],
-			backendConfigDir   = self.config['backendConfigDir'],
-			extensionConfigDir = self.config['extensionConfigDir'],
-			hostControlBackend = True,
-			hostControlSafeBackend = True,
-			depotBackend       = bool(self.config['depotId']),
-			messageBusNotifier = bool(self.config['messageBus']),
-			startReactor       = False,
+			dispatchConfigFile=self.config['dispatchConfigFile'],
+			backendConfigDir=self.config['backendConfigDir'],
+			extensionConfigDir=self.config['extensionConfigDir'],
+			hostControlBackend=True,
+			hostControlSafeBackend=True,
+			depotBackend=bool(self.config['depotId']),
+			messageBusNotifier=bool(self.config['messageBus']),
+			startReactor=False,
 			maxLogSize=self.config['maxlogsize'],
 		)
 		OpsiconfdHTTPChannel.backend = self._backend
@@ -274,24 +279,25 @@ class Opsiconfd(OpsiService):
 					% self.config['staticDirectories']['/']['path'])
 			else:
 				self._root = ResourceOpsiconfdDAV(self,
-					path = self.config['staticDirectories']['/']['path'],
-					readOnly = True,
-					authRequired = (not 'noauth' in (self.config['staticDirectories']['/']['options'])) )
+					path=self.config['staticDirectories']['/']['path'],
+					readOnly=True,
+					authRequired='noauth' not in self.config['staticDirectories']['/']['options']
+				)
 				logger.notice(u"Added static content '/' which points to directory '%s'" \
 					% self.config['staticDirectories']['/']['path'])
 
 		if not hasattr(self, '_root'):
 			self._root = ResourceRoot()
 
-		self._root.putChild('rrd',             ResourceOpsiconfdDAV(self, path = self.config['rrdDir'], readOnly = True))
-		self._root.putChild('rpc',             ResourceOpsiconfdJsonRpc(self))
-		self._root.putChild('interface',       ResourceOpsiconfdJsonInterface(self))
-		self._root.putChild('info',            ResourceOpsiconfdInfo(self))
-		self._root.putChild('monitoring',      ResourceOpsiconfdMonitoring(self))
+		self._root.putChild('rrd', ResourceOpsiconfdDAV(self, path=self.config['rrdDir'], readOnly=True))
+		self._root.putChild('rpc', ResourceOpsiconfdJsonRpc(self))
+		self._root.putChild('interface', ResourceOpsiconfdJsonInterface(self))
+		self._root.putChild('info', ResourceOpsiconfdInfo(self))
+		self._root.putChild('monitoring', ResourceOpsiconfdMonitoring(self))
 		# self._root.putChild('doc',             ResourceOpsiDocumentation())
-		self._root.putChild('configed.jnlp',   ResourceOpsiconfdConfigedJNLP())
+		self._root.putChild('configed.jnlp', ResourceOpsiconfdConfigedJNLP())
 
-		hosts = self._backend.host_getObjects(type = 'OpsiDepotserver', id = self.config['fqdn'])
+		hosts = self._backend.host_getObjects(type='OpsiDepotserver', id=self.config['fqdn'])
 		if hosts:
 			depot = hosts[0]
 			self.config['depotId'] = depot.getId()
@@ -324,7 +330,7 @@ class Opsiconfd(OpsiService):
 		for (name, pathAndOptions) in self.config['staticDirectories'].items():
 			path = pathAndOptions['path']
 			options = pathAndOptions['options']
-			if (name == '/'):
+			if name == '/':
 				continue
 
 			if name in ('rpc', 'interface', 'info'):
@@ -339,8 +345,8 @@ class Opsiconfd(OpsiService):
 			if name in ('repository', 'depot'):
 				readOnly = False
 
-			authRequired = not('noauth' in options)
-			self._root.putChild(name, ResourceOpsiconfdDAV(self, path, readOnly = readOnly, authRequired = authRequired))
+			authRequired = 'noauth' not in options
+			self._root.putChild(name, ResourceOpsiconfdDAV(self, path, readOnly=readOnly, authRequired=authRequired))
 			logger.notice(u"Added webdav content '%s' which points to directory '%s' %s" % (name, path, tuple(options)))
 
 		self._site = server.Site(self._root)
@@ -351,11 +357,11 @@ class Opsiconfd(OpsiService):
 		self._startListeningHTTPS()
 
 	def _startListeningHTTP(self, dontcare=None):
-		if (self.config['httpPort'] <= 0):
+		if self.config['httpPort'] <= 0:
 			self._httpPort = None
 			return
 
-		if (self.config['interface'] == '0.0.0.0'):
+		if self.config['interface'] == '0.0.0.0':
 			self._httpPort = reactor.listenTCP(
 				self.config['httpPort'],
 				OpsiconfdHTTPFactory(self._site)
@@ -364,17 +370,17 @@ class Opsiconfd(OpsiService):
 			self._httpPort = reactor.listenTCP(
 				self.config['httpPort'],
 				OpsiconfdHTTPFactory(self._site),
-				interface = self.config['interface']
+				interface=self.config['interface']
 			)
 
 		logger.notice(u"Accepting HTTP requests on %s:%s" % (self.config['interface'], self.config['httpPort']))
 
 	def _startListeningHTTPS(self, dontcare=None):
-		if (self.config['httpsPort'] <= 0):
+		if self.config['httpsPort'] <= 0:
 			self._httpsPort = None
 			return
 
-		if (self.config['interface'] == '0.0.0.0'):
+		if self.config['interface'] == '0.0.0.0':
 			self._httpsPort = reactor.listenSSL(
 				self.config['httpsPort'],
 				OpsiconfdHTTPFactory(self._site),
@@ -385,7 +391,7 @@ class Opsiconfd(OpsiService):
 				self.config['httpsPort'],
 				OpsiconfdHTTPFactory(self._site),
 				SSLContext(self.config['sslServerKeyFile'], self.config['sslServerCertFile']),
-				interface = self.config['interface']
+				interface=self.config['interface']
 			)
 
 		logger.notice(u"Accepting HTTPS requests on %s:%s" % (self.config['interface'], self.config['httpsPort']))
@@ -404,7 +410,7 @@ class Opsiconfd(OpsiService):
 
 		logger.notice(u"Publishing opsiconfd over zeroconf as '%s' on '%s'" % (name, port))
 		try:
-			self._zeroconfService = ZeroconfService(name = name, port = port)
+			self._zeroconfService = ZeroconfService(name=name, port=port)
 			self._zeroconfService.publish()
 		except Exception as e:
 			logger.error(u"Failed to publish opsiconfd over zeroconf: %s" % e)
@@ -426,7 +432,7 @@ class Opsiconfd(OpsiService):
 		from OPSI.Util.Debug import DebugShell
 
 		ns = globals()
-		ns.update({"opsiconfd":self})
+		ns.update({"opsiconfd": self})
 
 		self._debugShell = DebugShell(self, self._backend, namespace=ns)
 
@@ -435,7 +441,7 @@ class Opsiconfd(OpsiService):
 
 	def _startMessageBusServer(self):
 		self._messageBusServer = MessageBusServer()
-		self._messageBusServer.start(startReactor = False)
+		self._messageBusServer.start(startReactor=False)
 		self._messageBusService = MessageBusService()
 		OpsiconfdHTTPChannel.messageBusService = self._messageBusService
 		self._messageBusService.start()
@@ -477,6 +483,7 @@ class OpsiconfdInit(Application):
 		# Set umask
 		os.umask(0077)
 		self._pid = 0
+		self.config = {}
 
 		try:
 			(self.opts, self.args) = getopt.getopt(sys.argv[1:], "vc:f:l:p:P:i:D", ["profile=", "profiler=", "debug"])
@@ -487,10 +494,10 @@ class OpsiconfdInit(Application):
 		self.setDefaultConfig()
 		# Process command line arguments
 		for (opt, arg) in self.opts:
-			if (opt == "-c"):
+			if opt == "-c":
 				self.config['configFile'] = forceFilename(arg)
-			if  (opt == "-v"):
-				print u"opsiconfd version %s" % __version__
+			elif opt == "-v":
+				print(u"opsiconfd version {0}".format(__version__))
 				sys.exit(0)
 		self.readConfigFile()
 		self.setCommandlineConfig()
@@ -511,7 +518,7 @@ class OpsiconfdInit(Application):
 
 	def setup(self):
 		# Call signalHandler on signal SIGHUP, SIGTERM, SIGINT
-		signal(SIGHUP,  self.signalHandler)
+		signal(SIGHUP, self.signalHandler)
 
 		if self.config['daemon']:
 			daemonize()
@@ -526,89 +533,93 @@ class OpsiconfdInit(Application):
 
 	def setDefaultConfig(self):
 		self.config = {
-			'pidFile'                      : u'/var/run/opsiconfd/opsiconfd.pid',
-			'configFile'                   : u'/etc/opsi/opsiconfd.conf',
-			'daemon'                       : False,
-			'logLevel'                     : LOG_NOTICE,
-			'logFile'                      : u'/var/log/opsi/opsiconfd/opsiconfd.log',
-			'logFormat'                    : u'[%l] [%D] %M (%F|%N)',
-			'symlinkLogs'                  : False,
-			'httpPort'                     : 0,
-			'httpsPort'                    : 4447,
-			'interface'                    : u'0.0.0.0',
-			'adminNetworks'                : [ u'0.0.0.0/0' ],
-			'maxExecutionStatisticValues'  : 250,
-			'sslServerCertFile'            : u'/etc/opsi/opsiconfd.pem',
-			'sslServerKeyFile'             : u'/etc/opsi/opsiconfd.pem',
-			'sessionName'                  : u'OPSISID',
-			'maxSessionsPerIp'             : 25,
-			'maxAuthenticationFailures'    : 5,
-			'resolveVerifyIp'              : False,
-			'sessionMaxInactiveInterval'   : 120,
-			'updateIpAddress'              : False,
-			'staticDirectories'            : {},
-			'depotId'                      : None,
-			'fqdn'                         : forceHostId(getfqdn(conf='/etc/opsi/global.conf')),
-			'ipAddress'                    : socket.gethostbyname(socket.gethostname()),
-			'rrdDir'                       : u'/var/lib/opsiconfd/rrd',
-			'backendConfigDir'             : u'/etc/opsi/backends',
-			'dispatchConfigFile'           : u'/etc/opsi/backendManager/dispatch.conf',
-			'extensionConfigDir'           : u'/etc/opsi/backendManager/extend.d',
-			'aclFile'                      : u'/etc/opsi/backendManager/acl.conf',
-			'socket'                       : u'/var/run/opsiconfd/opsiconfd.socket',
-			'multiprocessing'              : False,
-			'loadbalancing'			: False,
-			'profile'                      : False,
-			'profiler'                     : u'profiler',
-			'debug'                        : False,
-			'messageBus'                   : False,
-			'monitoringUser'               : u"monitoring",
-			'monitoringDebug'            : False,
+			'pidFile': u'/var/run/opsiconfd/opsiconfd.pid',
+			'configFile': u'/etc/opsi/opsiconfd.conf',
+			'daemon': False,
+			'logLevel': LOG_NOTICE,
+			'logFile': u'/var/log/opsi/opsiconfd/opsiconfd.log',
+			'logFormat': u'[%l] [%D] %M (%F|%N)',
+			'symlinkLogs': False,
+			'maxlogsize': 5000000,
+			'httpPort': 0,
+			'httpsPort': 4447,
+			'interface': u'0.0.0.0',
+			'adminNetworks': [u'0.0.0.0/0'],
+			'maxExecutionStatisticValues': 250,
+			'sslServerCertFile': u'/etc/opsi/opsiconfd.pem',
+			'sslServerKeyFile': u'/etc/opsi/opsiconfd.pem',
+			'sessionName': u'OPSISID',
+			'maxSessionsPerIp': 25,
+			'maxAuthenticationFailures': 5,
+			'resolveVerifyIp': False,
+			'sessionMaxInactiveInterval': 120,
+			'updateIpAddress': False,
+			'staticDirectories': {},
+			'depotId': None,
+			'fqdn': forceHostId(getfqdn(conf='/etc/opsi/global.conf')),
+			'ipAddress': socket.gethostbyname(socket.gethostname()),
+			'rrdDir': u'/var/lib/opsiconfd/rrd',
+			'backendConfigDir': u'/etc/opsi/backends',
+			'dispatchConfigFile': u'/etc/opsi/backendManager/dispatch.conf',
+			'extensionConfigDir': u'/etc/opsi/backendManager/extend.d',
+			'aclFile': u'/etc/opsi/backendManager/acl.conf',
+			'socket': u'/var/run/opsiconfd/opsiconfd.socket',
+			'multiprocessing': False,
+			'loadbalancing': False,
+			'profile': False,
+			'profiler': u'profiler',
+			'debug': False,
+			'messageBus': False,
+			'monitoringUser': u"monitoring",
+			'monitoringDebug': False,
 		}
 
 	def setCommandlineConfig(self):
 		for (opt, arg) in self.opts:
-			if   (opt == "-D"):
+			if opt == "-D":
 				self.config['daemon'] = True
-			elif (opt == "-l"):
+			elif opt == "-l":
 				self.config['logLevel'] = forceInt(arg)
-			elif (opt == "-f"):
+			elif opt == "-f":
 				self.config['logFile'] = forceFilename(arg)
-			elif (opt == "-p"):
+			elif opt == "-p":
 				self.config['httpPort'] = forceInt(arg)
-			elif (opt == "-P"):
+			elif opt == "-P":
 				self.config['httpsPort'] = forceInt(arg)
-			elif (opt == "-i"):
+			elif opt == "-i":
 				self.config['interface'] = forceUnicode(arg)
-			elif (opt == "--profile"):
+			elif opt == "--profile":
 				self.config["profile"] = forceFilename(arg)
-			elif (opt == "--profiler"):
+			elif opt == "--profiler":
 				self.config["profiler"] = forceUnicode(arg)
-			elif (opt == "--debug"):
+			elif opt == "--debug":
 				self.config["debug"] = True
 
 	def createPidFile(self):
-		logger.info(u"Creating pid file '%s'" % self.config['pidFile'])
 		if not os.path.exists(os.path.dirname(self.config['pidFile'])):
+			logger.notice(u"Missing directory {0!r} - creating.".format(self.config['pidFile']))
 			os.makedirs(os.path.dirname(self.config['pidFile']))
 		elif os.path.exists(self.config['pidFile']) and os.access(self.config['pidFile'], os.R_OK | os.W_OK):
-			pf = open(self.config['pidFile'], 'r')
-			p = pf.readline().strip()
-			pf.close()
-			if p:
+			logger.notice(u"Found old pid file {0!r}".format(self.config['pidFile']))
+			with open(self.config['pidFile'], 'r') as pf:
+				pidFromFile = pf.readline().strip()
+
+			if pidFromFile:
 				running = False
 				try:
-					for i in execute("%s -x opsiconfd" % which("pidof"))[0].strip().split():
-						if (i == p):
+					for pid in execute("%s -x opsiconfd" % which("pidof"))[0].strip().split():
+						if pid == pidFromFile:
 							running = True
 							break
 				except Exception as e:
 					logger.error(e)
+
 				if running:
-					raise Exception(u"Another opsiconfd process is running (pid: %s), stop process first or change pidfile." % p )
+					raise Exception(u"Another opsiconfd process is running (pid: %s), stop process first or change pidfile." % pidFromFile)
 
 		pid = os.getpid()
 
+		logger.notice(u"Creating pid file {0!r}".format(self.config['pidFile']))
 		with open(self.config['pidFile'], "w") as pf:
 			pf.write(str(pid))
 
@@ -618,7 +629,7 @@ class OpsiconfdInit(Application):
 				with open(self.config['pidFile'], "r") as pf:
 					pid = pf.read().strip()
 
-				if (int(pid) == int(os.getpid())):
+				if int(pid) == int(os.getpid()):
 					logger.info(u"Removing pid file '%s'" % self.config['pidFile'])
 					os.unlink(self.config['pidFile'])
 		except Exception as e:
@@ -632,7 +643,7 @@ class OpsiconfdInit(Application):
 		for thread in threading.enumerate():
 			logger.debug(u"Running thread before signal: %s" % thread)
 
-		if (signo == SIGHUP):
+		if signo == SIGHUP:
 			if reactor and reactor.running and self._opsiconfd:
 				self.setDefaultConfig()
 				self.readConfigFile()
@@ -640,8 +651,9 @@ class OpsiconfdInit(Application):
 				self._opsiconfd.setConfig(self.config)
 				reactor.callFromThread(self._opsiconfd.reload)
 
-		if (signo == SIGTERM or signo == SIGINT):
+		if signo in (SIGTERM, SIGINT):
 			self.stop()
+
 		for thread in threading.enumerate():
 			logger.debug(u"Running thread after signal: %s" % thread)
 
@@ -650,95 +662,95 @@ class OpsiconfdInit(Application):
 		logger.notice(u"Trying to read config from file: '%s'" % self.config['configFile'])
 
 		try:
-			iniFile = IniFile(filename = self.config['configFile'], raw = True)
+			iniFile = IniFile(filename=self.config['configFile'], raw=True)
 			config = iniFile.parse()
 
 			for section in config.sections():
 				logger.debug(u"Processing section '%s' in config file: '%s'" % (section, self.config['configFile']))
-				if (section.lower() == 'global'):
+				if section.lower() == 'global':
 					# Global settings
 					for (option, value) in config.items(section):
-						if (option == 'pid file'):
+						if option == 'pid file':
 							self.config['pidFile'] = forceFilename(value)
-						elif (option == 'log level'):
+						elif option == 'log level':
 							self.config['logLevel'] = forceInt(value)
-						elif (option == 'log file'):
+						elif option == 'log file':
 							self.config['logFile'] = forceFilename(value)
-						elif (option == 'log format'):
+						elif option == 'log format':
 							self.config['logFormat'] = forceUnicode(value)
-						elif (option == 'max log size'):
-							self.config['maxlogsize'] = forceUnicode(value)
-						elif (option == 'symlink logs'):
+						elif option == 'max log size':
+							self.config['maxlogsize'] = removeUnit(value)
+						elif option == 'symlink logs':
 							self.config['symlinkLogs'] = forceBool(value)
-						elif (option == 'backend config dir'):
+						elif option == 'backend config dir':
 							self.config['backendConfigDir'] = forceFilename(value)
-						elif (option == 'dispatch config file'):
+						elif option == 'dispatch config file':
 							self.config['dispatchConfigFile'] = forceFilename(value)
-						elif (option == 'socket'):
+						elif option == 'socket':
 							self.config['socket'] = forceFilename(value)
-						elif (option == 'extension config dir'):
+						elif option == 'extension config dir':
 							self.config['extensionConfigDir'] = forceFilename(value)
-						elif (option == 'acl file'):
+						elif option == 'acl file':
 							self.config['aclFile'] = forceFilename(value)
-						elif (option == 'max execution statistics'):
+						elif option == 'max execution statistics':
 							self.config['maxExecutionStatisticValues'] = forceInt(value)
-						elif (option == 'multiprocessing'):
+						elif option == 'multiprocessing':
 							self.config['multiprocessing'] = forceBool(value)
-						elif (option == 'loadbalancing'):
+						elif option == 'loadbalancing':
 							self.config['loadbalancing'] = forceBool(value)
-						elif (option == 'admin networks'):
+						elif option == 'admin networks':
 							self.config['adminNetworks'] = []
 							for net in value.split(','):
 								self.config['adminNetworks'].append(forceNetworkAddress(net.strip()))
-						elif (option == 'message bus'):
+						elif option == 'message bus':
 							self.config['messageBus'] = forceBool(value)
-						elif (option == 'monitoring user'):
+						elif option == 'monitoring user':
 							self.config['monitoringUser'] = forceUnicode(value)
-						elif (option == 'monitoring debug'):
+						elif option == 'monitoring debug':
 							self.config['monitoringDebug'] = forceBool(value)
 						else:
 							logger.warning(u"Ignoring unknown option '%s' in config file: '%s'" % (option, self.config['configFile']))
 
-				elif (section.lower() == 'service'):
+				elif section.lower() == 'service':
 					# Service settings
 					for (option, value) in config.items(section):
-						if   (option == 'http port'):
+						if option == 'http port':
 							self.config['httpPort'] = forceInt(value)
-						elif (option == 'https port'):
+						elif option == 'https port':
 							self.config['httpsPort'] = forceInt(value)
-						elif (option == 'interface'):
+						elif option == 'interface':
 							self.config['interface'] = forceUnicode(value)
-						elif (option == 'ssl server cert'):
+						elif option == 'ssl server cert':
 							self.config['sslServerCertFile'] = forceFilename(value)
-						elif (option == 'ssl server key'):
+						elif option == 'ssl server key':
 							self.config['sslServerKeyFile'] = forceFilename(value)
 						else:
 							logger.warning(u"Ignoring unknown option '%s' in config file: '%s'" % (option, self.config['configFile']))
 
-				elif (section.lower() == 'session'):
+				elif section.lower() == 'session':
 					# Session settings
 					for (option, value) in config.items(section):
-						if   (option == 'session name'):
+						if option == 'session name':
 							self.config['sessionName'] = forceUnicode(value)
-						elif (option == 'verify ip'):
+						elif option == 'verify ip':
 							self.config['resolveVerifyIp'] = forceBool(value)
-						elif (option == 'update ip'):
+						elif option == 'update ip':
 							self.config['updateIpAddress'] = forceBool(value)
-						elif (option == 'max inactive interval'):
+						elif option == 'max inactive interval':
 							self.config['sessionMaxInactiveInterval'] = forceInt(value)
-						elif (option == 'max sessions per ip'):
+						elif option == 'max sessions per ip':
 							self.config['maxSessionsPerIp'] = forceInt(value)
-						elif (option == 'max authentication failures'):
+						elif option == 'max authentication failures':
 							self.config['maxAuthenticationFailures'] = forceInt(value)
 						else:
 							logger.warning(u"Ignoring unknown option '%s' in config file: '%s'" % (option, self.config['configFile']))
 
-				elif (section.lower() == 'directories'):
+				elif section.lower() == 'directories':
 					# Static directories
 					self.config['staticDirectories'] = {}
 					for (directory, path) in config.items(section):
 						opt = []
-						if (path.find('(') != -1):
+						if '(' in path:
 							(path, opt) = path.split('(', 1)
 							path = path.strip()
 							opt = opt.lower().replace(')', '').strip().split(',')
@@ -748,33 +760,33 @@ class OpsiconfdInit(Application):
 				else:
 					logger.warning(u"Ignoring unknown section '%s' in config file: '%s'" % (section, self.config['configFile']))
 
-		except Exception as e:
+		except Exception as error:
 			# An error occured while trying to read the config file
-			logger.error(u"Failed to read config file '%s': %s" % (self.config['configFile'], e))
-			logger.logException(e)
+			logger.error(u"Failed to read config file '%s': %s" % (self.config['configFile'], error))
+			logger.logException(error)
 			raise
+
 		logger.notice(u"Config read")
 
 	def usage(self):
-		print u"\nUsage: %s [-D] [-c <filename>] [-f <filename>] [-l <log level>] [-i <ipaddress>] [-p <http port>] [-P <https port>]" % os.path.basename(sys.argv[0])
-		print u"Options:"
-		print u"  -v    Show version information and exit"
-		print u"  -D    Causes the server to operate as a daemon"
-		print u"  -p    HTTP Port to listen on (0 to disable)"
-		print u"  -P    HTTPS Port to listen on (0 to disable)"
-		print u"  -i    IP address of interface to listen on (default: 0.0.0.0)"
-		print u"  -f    Log to given file instead of syslog"
-		print u"  -c    Location of config file"
-		print u"  -s    Location of socket (default: /var/run/opsiconfd/opsiconfd.socket"
-		print u"  -l    Set log level (default: 4)"
-		print u"        0=nothing, 1=essential, 2=critical, 3=error, 4=warning"
-		print u"        5=notice, 6=info, 7=debug, 8=debug2, 9=confidential"
-		print u""
+		print(u"\nUsage: %s [-D] [-c <filename>] [-f <filename>] [-l <log level>] [-i <ipaddress>] [-p <http port>] [-P <https port>]" % os.path.basename(sys.argv[0]))
+		print(u"Options:")
+		print(u"  -v    Show version information and exit")
+		print(u"  -D    Causes the server to operate as a daemon")
+		print(u"  -p    HTTP Port to listen on (0 to disable)")
+		print(u"  -P    HTTPS Port to listen on (0 to disable)")
+		print(u"  -i    IP address of interface to listen on (default: 0.0.0.0)")
+		print(u"  -f    Log to given file instead of syslog")
+		print(u"  -c    Location of config file")
+		print(u"  -s    Location of socket (default: /var/run/opsiconfd/opsiconfd.socket")
+		print(u"  -l    Set log level (default: 4)")
+		print(u"        0=nothing, 1=essential, 2=critical, 3=error, 4=warning")
+		print(u"        5=notice, 6=info, 7=debug, 8=debug2, 9=confidential")
+		print(u"")
 
 
 def main():
 	logger.setConsoleLevel(LOG_WARNING)
-	exception = None
 
 	try:
 		OpsiconfdInit()
@@ -782,10 +794,10 @@ def main():
 		pass
 	except Exception as exception:
 		logger.logException(exception)
-		print >> sys.stderr, u"ERROR:", unicode(exception)
-		return(1)
+		print(u"ERROR: {0}".format(unicode(exception)), file=sys.stderr)
+		return 1
 
-	return(0)
+	return 0
 
-if (__name__ == "__main__"):
+if __name__ == "__main__":
 	sys.exit(main())
